﻿using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Build.Framework;
using Microsoft.Build.Utilities;

namespace DebugTask
{
    /// <summary>
    /// From: http://ozgrant.com/2008/04/04/createguid-msbuild-task/
    /// 
    /// This task creates a new GUID using System.Guid.NewGuid()
    /// 
    /// The Format parameter is optional.
    /// 
    /// <example>
    /// <code source="Sedodream.MSBuild.Tasks\SampleTargets\CreateGuidSample.targets" 
    ///                 title="Sample" lang="XML" tabSize="4" />
    /// </example>
    /// <see>http://ozgrant.com/2008/04/04/createguid-msbuild-task/</see>
    /// </summary>
    public class CreateGuid : Task
    {
        #region Fields
        private string mFormat;
        private string mOutput;
        #endregion
        /// <summary>
        /// The format specifier of the GUID.
        /// Must be one of "N" "D" "B" "P" ""
        /// Default is "D"
        /// 
        /// N = 32 digits: xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
        /// D = 32 digits separated by hyphens: xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx
        /// B = 32 digits separated by hyphens, enclosed in brackets: {xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx}
        /// P = 32 digits separated by hyphens, enclosed in parentheses: (xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx) 
        /// </summary>
        public string Format { get{return mFormat;} set{mFormat = value;} }
        /// <summary>
        /// Outputs a new GUID in the default format: xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx
        /// </summary>
        [Output]
        public String Output { get { return mOutput; } set { mOutput = value; } }
        /// <summary>
        /// Executes the task.
        /// </summary>
        /// <returns></returns>
        public override bool Execute()
        {
            try
            {
                Output = Guid.NewGuid().ToString(Format);
                Log.LogMessage("GUID Created: {0}", Output);
            }
            catch (FormatException e)
            {
                Log.LogErrorFromException(e);
                return false;
            }

            return true;
        }
    }
}
